[//]: # ( [![PyPI package](https://img.shields.io/pypi/v/karr_lab_aws_manager.svg)](https://pypi.python.org/pypi/karr_lab_aws_manager) )
[![Documentation](https://readthedocs.org/projects/karr-lab-aws-manager-test-0/badge/?version=latest)](https://docs.karrlab.org/karr_lab_aws_manager)
[![Test results](https://circleci.com/gh/KarrLab/karr_lab_aws_manager.svg?style=shield)](https://circleci.com/gh/KarrLab/karr_lab_aws_manager)
[![Test coverage](https://coveralls.io/repos/github/KarrLab/karr_lab_aws_manager/badge.svg)](https://coveralls.io/github/KarrLab/karr_lab_aws_manager)
[![Code analysis](https://api.codeclimate.com/v1/badges/7fc32466c8663ffedc4d/maintainability)](https://codeclimate.com/github/KarrLab/karr_lab_aws_manager)
[![License](https://img.shields.io/github/license/KarrLab/karr_lab_aws_manager.svg)](LICENSE)
![Analytics](https://ga-beacon.appspot.com/UA-86759801-1/karr_lab_aws_manager/README.md?pixel)

# karr_lab_aws_manager

Write an overview

## Installation
1. Install dependencies
2. Install the latest release from PyPI
  ```
  pip install karr_lab_aws_manager.git[all]
  ```
3. Install the latest revision from GitHub
  ```
  pip install git+https://github.com/KarrLab/karr_lab_aws_manager.git#egg=karr_lab_aws_manager[all]
  ```

## Documentation
Please see the [API documentation](https://docs.karrlab.org/karr_lab_aws_manager).

## License
The package is released under the [MIT license](LICENSE).

## Development team
This package was developed by the [Karr Lab](https://www.karrlab.org) at the Icahn School of Medicine at Mount Sinai in New York, USA.

## Questions and comments
Please contact the [Karr Lab](mailto:info@karrlab.org) with any questions or comments.